==> verticalpodautoscaler-model-v1-6.2.0-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/VerticalPodAutoscalerListFluent.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface VerticalPodAutoscalerListFluent<A extends VerticalPodAutoscalerListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,VerticalPodAutoscaler item);
  public A setToItems(Integer index,VerticalPodAutoscaler item);
  public A addToItems(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscaler... items);
  public A addAllToItems(Collection<VerticalPodAutoscaler> items);
  public A removeFromItems(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscaler... items);
  public A removeAllFromItems(Collection<VerticalPodAutoscaler> items);
  public A removeMatchingFromItems(Predicate<VerticalPodAutoscalerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<VerticalPodAutoscaler> getItems();
  public List<VerticalPodAutoscaler> buildItems();
  public VerticalPodAutoscaler buildItem(Integer index);
  public VerticalPodAutoscaler buildFirstItem();
  public VerticalPodAutoscaler buildLastItem();
  public VerticalPodAutoscaler buildMatchingItem(Predicate<VerticalPodAutoscalerBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<VerticalPodAutoscalerBuilder> predicate);
  public A withItems(List<VerticalPodAutoscaler> items);
  public A withItems(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscaler... items);
  public Boolean hasItems();
  public VerticalPodAutoscalerListFluent.ItemsNested<A> addNewItem();
  public VerticalPodAutoscalerListFluent.ItemsNested<A> addNewItemLike(VerticalPodAutoscaler item);
  public VerticalPodAutoscalerListFluent.ItemsNested<A> setNewItemLike(Integer index,VerticalPodAutoscaler item);
  public VerticalPodAutoscalerListFluent.ItemsNested<A> editItem(Integer index);
  public VerticalPodAutoscalerListFluent.ItemsNested<A> editFirstItem();
  public VerticalPodAutoscalerListFluent.ItemsNested<A> editLastItem();
  public VerticalPodAutoscalerListFluent.ItemsNested<A> editMatchingItem(Predicate<VerticalPodAutoscalerBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,VerticalPodAutoscalerFluent<VerticalPodAutoscalerListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> verticalpodautoscaler-model-v1-6.7.2-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/VerticalPodAutoscalerListFluent.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface VerticalPodAutoscalerListFluent<A extends VerticalPodAutoscalerListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,VerticalPodAutoscaler item);
  public A setToItems(int index,VerticalPodAutoscaler item);
  public A addToItems(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscaler... items);
  public A addAllToItems(Collection<VerticalPodAutoscaler> items);
  public A removeFromItems(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscaler... items);
  public A removeAllFromItems(Collection<VerticalPodAutoscaler> items);
  public A removeMatchingFromItems(Predicate<VerticalPodAutoscalerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<VerticalPodAutoscaler> getItems();
  public List<VerticalPodAutoscaler> buildItems();
  public VerticalPodAutoscaler buildItem(int index);
  public VerticalPodAutoscaler buildFirstItem();
  public VerticalPodAutoscaler buildLastItem();
  public VerticalPodAutoscaler buildMatchingItem(Predicate<VerticalPodAutoscalerBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<VerticalPodAutoscalerBuilder> predicate);
  public A withItems(List<VerticalPodAutoscaler> items);
  public A withItems(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscaler... items);
  public Boolean hasItems();
  public VerticalPodAutoscalerListFluent.ItemsNested<A> addNewItem();
  public VerticalPodAutoscalerListFluent.ItemsNested<A> addNewItemLike(VerticalPodAutoscaler item);
  public VerticalPodAutoscalerListFluent.ItemsNested<A> setNewItemLike(int index,VerticalPodAutoscaler item);
  public VerticalPodAutoscalerListFluent.ItemsNested<A> editItem(int index);
  public VerticalPodAutoscalerListFluent.ItemsNested<A> editFirstItem();
  public VerticalPodAutoscalerListFluent.ItemsNested<A> editLastItem();
  public VerticalPodAutoscalerListFluent.ItemsNested<A> editMatchingItem(Predicate<VerticalPodAutoscalerBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,VerticalPodAutoscalerFluent<VerticalPodAutoscalerListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
